@@ -37,12 +37,8 @@ func (rsmi *ROCmSMI) Gather(acc telegraf.Accumulator) error {
 		return fmt.Errorf("rocm-smi binary not found in path %s, cannot query GPUs statistics", rsmi.BinPath)
 	}
 
-	data, err := rsmi.pollROCmSMI()
-	if err != nil {
-		return err
-	}
-
-	err = gatherROCmSMI(data, acc)
+	data := rsmi.pollROCmSMI()
+	err := gatherROCmSMI(data, acc)
 	if err != nil {
 		return err
 	}
@@ -59,7 +55,7 @@ func init() {
 	})
 }
 
-func (rsmi *ROCmSMI) pollROCmSMI() ([]byte, error) {
+func (rsmi *ROCmSMI) pollROCmSMI() []byte {
 	// Construct and execute metrics query, there currently exist (ROCm v4.3.x) a "-a" option
 	// that does not provide all the information, so each needed parameter is set manually
 	cmd := exec.Command(rsmi.BinPath,
@@ -102,9 +98,8 @@ func (rsmi *ROCmSMI) pollROCmSMI() ([]byte, error) {
 		"--showtoponuma",
 		"--json")
 
-	ret, _ := internal.StdOutputTimeout(cmd,
-		time.Duration(rsmi.Timeout))
-	return ret, nil
+	ret, _ := internal.StdOutputTimeout(cmd, time.Duration(rsmi.Timeout))
+	return ret
 }
 
 func gatherROCmSMI(ret []byte, acc telegraf.Accumulator) error {
