@@ -21,8 +21,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -82,10 +80,19 @@ var (
 
 	deviceFieldIds = map[string]string{
 		"1":   "read_error_rate",
+		"5":   "reallocated_sectors_count",
 		"7":   "seek_error_rate",
+		"10":  "spin_retry_count",
+		"184": "end_to_end_error",
+		"187": "uncorrectable_errors",
+		"188": "command_timeout",
 		"190": "temp_c",
 		"194": "temp_c",
+		"196": "realloc_event_count",
+		"197": "pending_sector_count",
+		"198": "uncorrectable_sector_count",
 		"199": "udma_crc_errors",
+		"201": "soft_read_error_rate",
 	}
 
 	// There are some fields we're interested in which use the vendor specific device ids
@@ -409,7 +416,10 @@ func (m *Smart) Init() error {
 	if err != nil {
 		m.PathNVMe = ""
 		//without nvme, plugin will not be able to gather vendor specific attributes (but it can work without it)
-		m.Log.Warnf("nvme not found: verify that nvme is installed and it is in your PATH (or specified in config) to gather vendor specific attributes: %s", err.Error())
+		m.Log.Warnf(
+			"nvme not found: verify that nvme is installed and it is in your PATH (or specified in config) to gather vendor specific attributes: %s",
+			err.Error(),
+		)
 	}
 
 	return nil
@@ -557,7 +567,7 @@ func (m *Smart) getVendorNVMeAttributes(acc telegraf.Accumulator, devices []stri
 
 	for _, device := range nvmeDevices {
 		if contains(m.EnableExtensions, "auto-on") {
-			// nolint:revive // one case switch on purpose to demonstrate potential extensions
+			//nolint:revive // one case switch on purpose to demonstrate potential extensions
 			switch device.vendorID {
 			case intelVID:
 				wg.Add(1)
@@ -586,8 +596,7 @@ func (m *Smart) getVendorNVMeAttributes(acc telegraf.Accumulator, devices []stri
 }
 
 func getDeviceInfoForNVMeDisks(acc telegraf.Accumulator, devices []string, nvme string, timeout config.Duration, useSudo bool) []nvmeDevice {
-	var nvmeDevices []nvmeDevice
-
+	nvmeDevices := make([]nvmeDevice, 0, len(devices))
 	for _, device := range devices {
 		newDevice, err := gatherNVMeDeviceInfo(nvme, device, timeout, useSudo)
 		if err != nil {
