@@ -16,7 +16,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
@@ -526,10 +525,7 @@ func (h *Host) SNMPGet(acc telegraf.Accumulator, initNode Node) error {
 			return err3
 		}
 		// Handle response
-		_, err = h.HandleResponse(oidsList, result, acc, initNode)
-		if err != nil {
-			return err
-		}
+		h.HandleResponse(oidsList, result, acc, initNode)
 	}
 	return nil
 }
@@ -569,10 +565,7 @@ func (h *Host) SNMPBulk(acc telegraf.Accumulator, initNode Node) error {
 				return err3
 			}
 			// Handle response
-			lastOid, err := h.HandleResponse(oidsList, result, acc, initNode)
-			if err != nil {
-				return err
-			}
+			lastOid := h.HandleResponse(oidsList, result, acc, initNode)
 			// Determine if we need more requests
 			if strings.HasPrefix(lastOid, oidAsked) {
 				needMoreRequests = true
@@ -629,7 +622,7 @@ func (h *Host) HandleResponse(
 	result *gosnmp.SnmpPacket,
 	acc telegraf.Accumulator,
 	initNode Node,
-) (string, error) {
+) string {
 	var lastOid string
 	for _, variable := range result.Variables {
 		lastOid = variable.Name
@@ -709,7 +702,7 @@ func (h *Host) HandleResponse(
 			}
 		}
 	}
-	return lastOid, nil
+	return lastOid
 }
 
 func init() {
