@@ -1,6 +1,5 @@
 //go:generate ../../../tools/readme_config_includer/generator
 //go:build windows
-// +build windows
 
 // Package win_eventlog Input plugin to collect Windows Event Log messages
 //
@@ -25,8 +24,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -51,8 +48,6 @@ type WinEventLog struct {
 
 var bufferSize = 1 << 14
 
-var description = "Input plugin to collect Windows Event Log messages"
-
 func (*WinEventLog) SampleConfig() string {
 	return sampleConfig
 }
@@ -64,7 +59,7 @@ func (w *WinEventLog) Gather(acc telegraf.Accumulator) error {
 	if w.subscription == 0 {
 		w.subscription, err = w.evtSubscribe(w.EventlogName, w.Query)
 		if err != nil {
-			return fmt.Errorf("Windows Event Log subscription error: %v", err.Error())
+			return fmt.Errorf("subscription of Windows Event Log failed: %w", err)
 		}
 	}
 	w.Log.Debug("Subscription handle id:", w.subscription)
@@ -77,7 +72,7 @@ loop:
 			case err == ERROR_NO_MORE_ITEMS:
 				break loop
 			case err != nil:
-				w.Log.Error("Error getting events:", err.Error())
+				w.Log.Errorf("Error getting events: %v", err)
 				return err
 			}
 		}
@@ -308,7 +303,6 @@ func (w *WinEventLog) fetchEvents(subsHandle EvtHandle) ([]Event, error) {
 		if eventHandle != 0 {
 			event, err := w.renderEvent(eventHandle)
 			if err == nil {
-				// w.Log.Debugf("Got event: %v", event)
 				events = append(events, event)
 			}
 		}
@@ -336,6 +330,7 @@ func (w *WinEventLog) renderEvent(eventHandle EvtHandle) (Event, error) {
 	if err != nil {
 		return event, err
 	}
+
 	err = xml.Unmarshal([]byte(eventXML), &event)
 	if err != nil {
 		// We can return event without most text values,
@@ -344,6 +339,19 @@ func (w *WinEventLog) renderEvent(eventHandle EvtHandle) (Event, error) {
 		return event, nil
 	}
 
+	// Do resolve local messages the usual way, while using built-in information for events forwarded by WEC.
+	// This is a safety measure as the underlying Windows-internal EvtFormatMessage might segfault in cases
+	// where the publisher (i.e. the remote machine which forwared the event) is unavailable e.g. due to
+	// a reboot. See https://github.com/influxdata/telegraf/issues/12328 for the full story.
+	if event.RenderingInfo == nil {
+		return w.renderLocalMessage(event, eventHandle)
+	}
+
+	// We got 'RenderInfo' elements, so try to apply them in the following function
+	return w.renderRemoteMessage(event)
+}
+
+func (w *WinEventLog) renderLocalMessage(event Event, eventHandle EvtHandle) (Event, error) {
 	publisherHandle, err := openPublisherMetadata(0, event.Source.Name, w.Locale)
 	if err != nil {
 		return event, nil
@@ -379,6 +387,32 @@ func (w *WinEventLog) renderEvent(eventHandle EvtHandle) (Event, error) {
 	return event, nil
 }
 
+func (w *WinEventLog) renderRemoteMessage(event Event) (Event, error) {
+	// Populating text values from RenderingInfo part of the XML
+	if len(event.RenderingInfo.Keywords) > 0 {
+		event.Keywords = strings.Join(event.RenderingInfo.Keywords, ",")
+	}
+	if event.RenderingInfo.Message != "" {
+		message := event.RenderingInfo.Message
+		if w.OnlyFirstLineOfMessage {
+			scanner := bufio.NewScanner(strings.NewReader(message))
+			scanner.Scan()
+			message = scanner.Text()
+		}
+		event.Message = message
+	}
+	if event.RenderingInfo.Level != "" {
+		event.LevelText = event.RenderingInfo.Level
+	}
+	if event.RenderingInfo.Task != "" {
+		event.TaskText = event.RenderingInfo.Task
+	}
+	if event.RenderingInfo.Opcode != "" {
+		event.OpcodeText = event.RenderingInfo.Opcode
+	}
+	return event, nil
+}
+
 func formatEventString(
 	messageFlag EvtFormatMessageFlag,
 	eventHandle EvtHandle,
@@ -391,6 +425,11 @@ func formatEventString(
 		return "", err
 	}
 
+	// Handle empty elements
+	if bufferUsed < 1 {
+		return "", nil
+	}
+
 	bufferUsed *= 2
 	buffer := make([]byte, bufferUsed)
 	bufferUsed = 0
