@@ -9,12 +9,12 @@ import (
 	"github.com/aws/aws-sdk-go-v2/service/kinesis"
 	"github.com/aws/aws-sdk-go-v2/service/kinesis/types"
 	"github.com/gofrs/uuid"
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/plugins/serializers"
 	"github.com/influxdata/telegraf/plugins/serializers/influx"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 const testPartitionKey = "partitionKey"
@@ -24,7 +24,6 @@ const testStreamName = "streamName"
 const zero int64 = 0
 
 func TestPartitionKey(t *testing.T) {
-	assert := assert.New(t)
 	testPoint := testutil.TestMetric(1)
 
 	k := KinesisOutput{
@@ -34,7 +33,7 @@ func TestPartitionKey(t *testing.T) {
 			Key:    "-",
 		},
 	}
-	assert.Equal("-", k.getPartitionKey(testPoint), "PartitionKey should be '-'")
+	require.Equal(t, "-", k.getPartitionKey(testPoint), "PartitionKey should be '-'")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -43,7 +42,7 @@ func TestPartitionKey(t *testing.T) {
 			Key:    "tag1",
 		},
 	}
-	assert.Equal(testPoint.Tags()["tag1"], k.getPartitionKey(testPoint), "PartitionKey should be value of 'tag1'")
+	require.Equal(t, testPoint.Tags()["tag1"], k.getPartitionKey(testPoint), "PartitionKey should be value of 'tag1'")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -53,7 +52,7 @@ func TestPartitionKey(t *testing.T) {
 			Default: "somedefault",
 		},
 	}
-	assert.Equal("somedefault", k.getPartitionKey(testPoint), "PartitionKey should use default")
+	require.Equal(t, "somedefault", k.getPartitionKey(testPoint), "PartitionKey should use default")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -62,7 +61,7 @@ func TestPartitionKey(t *testing.T) {
 			Key:    "doesnotexist",
 		},
 	}
-	assert.Equal("telegraf", k.getPartitionKey(testPoint), "PartitionKey should be telegraf")
+	require.Equal(t, "telegraf", k.getPartitionKey(testPoint), "PartitionKey should be telegraf")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -70,7 +69,7 @@ func TestPartitionKey(t *testing.T) {
 			Method: "not supported",
 		},
 	}
-	assert.Equal("", k.getPartitionKey(testPoint), "PartitionKey should be value of ''")
+	require.Equal(t, "", k.getPartitionKey(testPoint), "PartitionKey should be value of ''")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -78,7 +77,7 @@ func TestPartitionKey(t *testing.T) {
 			Method: "measurement",
 		},
 	}
-	assert.Equal(testPoint.Name(), k.getPartitionKey(testPoint), "PartitionKey should be value of measurement name")
+	require.Equal(t, testPoint.Name(), k.getPartitionKey(testPoint), "PartitionKey should be value of measurement name")
 
 	k = KinesisOutput{
 		Log: testutil.Logger{},
@@ -88,14 +87,14 @@ func TestPartitionKey(t *testing.T) {
 	}
 	partitionKey := k.getPartitionKey(testPoint)
 	u, err := uuid.FromString(partitionKey)
-	assert.Nil(err, "Issue parsing UUID")
-	assert.Equal(byte(4), u.Version(), "PartitionKey should be UUIDv4")
+	require.NoError(t, err, "Issue parsing UUID")
+	require.Equal(t, byte(4), u.Version(), "PartitionKey should be UUIDv4")
 
 	k = KinesisOutput{
 		Log:          testutil.Logger{},
 		PartitionKey: "-",
 	}
-	assert.Equal("-", k.getPartitionKey(testPoint), "PartitionKey should be '-'")
+	require.Equal(t, "-", k.getPartitionKey(testPoint), "PartitionKey should be '-'")
 
 	k = KinesisOutput{
 		Log:                testutil.Logger{},
@@ -103,13 +102,11 @@ func TestPartitionKey(t *testing.T) {
 	}
 	partitionKey = k.getPartitionKey(testPoint)
 	u, err = uuid.FromString(partitionKey)
-	assert.Nil(err, "Issue parsing UUID")
-	assert.Equal(byte(4), u.Version(), "PartitionKey should be UUIDv4")
+	require.NoError(t, err, "Issue parsing UUID")
+	require.Equal(t, byte(4), u.Version(), "PartitionKey should be UUIDv4")
 }
 
 func TestWriteKinesis_WhenSuccess(t *testing.T) {
-	assert := assert.New(t)
-
 	records := []types.PutRecordsRequestEntry{
 		{
 			PartitionKey: aws.String(testPartitionKey),
@@ -135,7 +132,7 @@ func TestWriteKinesis_WhenSuccess(t *testing.T) {
 	}
 
 	elapsed := k.writeKinesis(records)
-	assert.GreaterOrEqual(elapsed.Nanoseconds(), zero)
+	require.GreaterOrEqual(t, elapsed.Nanoseconds(), zero)
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -146,8 +143,6 @@ func TestWriteKinesis_WhenSuccess(t *testing.T) {
 }
 
 func TestWriteKinesis_WhenRecordErrors(t *testing.T) {
-	assert := assert.New(t)
-
 	records := []types.PutRecordsRequestEntry{
 		{
 			PartitionKey: aws.String(testPartitionKey),
@@ -173,7 +168,7 @@ func TestWriteKinesis_WhenRecordErrors(t *testing.T) {
 	}
 
 	elapsed := k.writeKinesis(records)
-	assert.GreaterOrEqual(elapsed.Nanoseconds(), zero)
+	require.GreaterOrEqual(t, elapsed.Nanoseconds(), zero)
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -184,8 +179,6 @@ func TestWriteKinesis_WhenRecordErrors(t *testing.T) {
 }
 
 func TestWriteKinesis_WhenServiceError(t *testing.T) {
-	assert := assert.New(t)
-
 	records := []types.PutRecordsRequestEntry{
 		{
 			PartitionKey: aws.String(testPartitionKey),
@@ -205,7 +198,7 @@ func TestWriteKinesis_WhenServiceError(t *testing.T) {
 	}
 
 	elapsed := k.writeKinesis(records)
-	assert.GreaterOrEqual(elapsed.Nanoseconds(), zero)
+	require.GreaterOrEqual(t, elapsed.Nanoseconds(), zero)
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -216,7 +209,6 @@ func TestWriteKinesis_WhenServiceError(t *testing.T) {
 }
 
 func TestWrite_NoMetrics(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 	svc := &mockKinesisPutRecords{}
 
@@ -232,13 +224,12 @@ func TestWrite_NoMetrics(t *testing.T) {
 	}
 
 	err := k.Write([]telegraf.Metric{})
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{})
 }
 
 func TestWrite_SingleMetric(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -257,7 +248,7 @@ func TestWrite_SingleMetric(t *testing.T) {
 
 	metric, metricData := createTestMetric(t, "metric1", serializer)
 	err := k.Write([]telegraf.Metric{metric})
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -273,7 +264,6 @@ func TestWrite_SingleMetric(t *testing.T) {
 }
 
 func TestWrite_MultipleMetrics_SinglePartialRequest(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -292,7 +282,7 @@ func TestWrite_MultipleMetrics_SinglePartialRequest(t *testing.T) {
 
 	metrics, metricsData := createTestMetrics(t, 3, serializer)
 	err := k.Write(metrics)
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -305,7 +295,6 @@ func TestWrite_MultipleMetrics_SinglePartialRequest(t *testing.T) {
 }
 
 func TestWrite_MultipleMetrics_SingleFullRequest(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -324,7 +313,7 @@ func TestWrite_MultipleMetrics_SingleFullRequest(t *testing.T) {
 
 	metrics, metricsData := createTestMetrics(t, maxRecordsPerRequest, serializer)
 	err := k.Write(metrics)
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -337,7 +326,6 @@ func TestWrite_MultipleMetrics_SingleFullRequest(t *testing.T) {
 }
 
 func TestWrite_MultipleMetrics_MultipleRequests(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -357,7 +345,7 @@ func TestWrite_MultipleMetrics_MultipleRequests(t *testing.T) {
 
 	metrics, metricsData := createTestMetrics(t, maxRecordsPerRequest+1, serializer)
 	err := k.Write(metrics)
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -376,7 +364,6 @@ func TestWrite_MultipleMetrics_MultipleRequests(t *testing.T) {
 }
 
 func TestWrite_MultipleMetrics_MultipleFullRequests(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -396,7 +383,7 @@ func TestWrite_MultipleMetrics_MultipleFullRequests(t *testing.T) {
 
 	metrics, metricsData := createTestMetrics(t, maxRecordsPerRequest*2, serializer)
 	err := k.Write(metrics)
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
 		{
@@ -415,7 +402,6 @@ func TestWrite_MultipleMetrics_MultipleFullRequests(t *testing.T) {
 }
 
 func TestWrite_SerializerError(t *testing.T) {
-	assert := assert.New(t)
 	serializer := influx.NewSerializer()
 
 	svc := &mockKinesisPutRecords{}
@@ -443,7 +429,7 @@ func TestWrite_SerializerError(t *testing.T) {
 		invalidMetric,
 		metric2,
 	})
-	assert.Nil(err, "Should not return error")
+	require.NoError(t, err, "Should not return error")
 
 	// remaining valid metrics should still get written
 	svc.AssertRequests(t, []*kinesis.PutRecordsInput{
@@ -519,7 +505,7 @@ func (m *mockKinesisPutRecords) SetupErrorResponse(err error) {
 func (m *mockKinesisPutRecords) PutRecords(_ context.Context, input *kinesis.PutRecordsInput, _ ...func(*kinesis.Options)) (*kinesis.PutRecordsOutput, error) {
 	reqNum := len(m.requests)
 	if reqNum > len(m.responses) {
-		return nil, fmt.Errorf("Response for request %+v not setup", reqNum)
+		return nil, fmt.Errorf("response for request %+v not setup", reqNum)
 	}
 
 	m.requests = append(m.requests, input)
@@ -595,14 +581,14 @@ func createTestMetrics(
 	count uint32,
 	serializer serializers.Serializer,
 ) ([]telegraf.Metric, [][]byte) {
-	metrics := make([]telegraf.Metric, count)
-	metricsData := make([][]byte, count)
+	metrics := make([]telegraf.Metric, 0, count)
+	metricsData := make([][]byte, 0, count)
 
 	for i := uint32(0); i < count; i++ {
 		name := fmt.Sprintf("metric%d", i)
 		metric, data := createTestMetric(t, name, serializer)
-		metrics[i] = metric
-		metricsData[i] = data
+		metrics = append(metrics, metric)
+		metricsData = append(metricsData, data)
 	}
 
 	return metrics, metricsData
@@ -611,14 +597,13 @@ func createTestMetrics(
 func createPutRecordsRequestEntries(
 	metricsData [][]byte,
 ) []types.PutRecordsRequestEntry {
-	count := len(metricsData)
-	records := make([]types.PutRecordsRequestEntry, count)
+	records := make([]types.PutRecordsRequestEntry, 0, len(metricsData))
 
-	for i := 0; i < count; i++ {
-		records[i] = types.PutRecordsRequestEntry{
+	for _, data := range metricsData {
+		records = append(records, types.PutRecordsRequestEntry{
 			PartitionKey: aws.String(testPartitionKey),
-			Data:         metricsData[i],
-		}
+			Data:         data,
+		})
 	}
 
 	return records
