@@ -2,41 +2,40 @@ package opentelemetry
 
 import (
 	"context"
-	"go.opentelemetry.io/collector/pdata/pcommon"
-	"go.opentelemetry.io/collector/pdata/pmetric"
-	"go.opentelemetry.io/collector/pdata/pmetric/pmetricotlp"
-	"google.golang.org/grpc/credentials/insecure"
 	"net"
-	"strings"
 	"testing"
 	"time"
 
 	"github.com/influxdata/influxdb-observability/common"
 	"github.com/influxdata/influxdb-observability/influx2otel"
+	"github.com/stretchr/testify/require"
+	"go.opentelemetry.io/collector/pdata/pcommon"
+	"go.opentelemetry.io/collector/pdata/pmetric"
+	"go.opentelemetry.io/collector/pdata/pmetric/pmetricotlp"
+	"google.golang.org/grpc"
+	"google.golang.org/grpc/credentials/insecure"
+	"google.golang.org/grpc/metadata"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
-	"google.golang.org/grpc"
-	"google.golang.org/grpc/metadata"
 )
 
 func TestOpenTelemetry(t *testing.T) {
 	expect := pmetric.NewMetrics()
 	{
 		rm := expect.ResourceMetrics().AppendEmpty()
-		rm.Resource().Attributes().InsertString("host.name", "potato")
-		rm.Resource().Attributes().InsertString("attr-key", "attr-val")
+		rm.Resource().Attributes().PutStr("host.name", "potato")
+		rm.Resource().Attributes().PutStr("attr-key", "attr-val")
 		ilm := rm.ScopeMetrics().AppendEmpty()
 		ilm.Scope().SetName("My Library Name")
 		m := ilm.Metrics().AppendEmpty()
 		m.SetName("cpu_temp")
-		m.SetDataType(pmetric.MetricDataTypeGauge)
+		m.SetEmptyGauge()
 		dp := m.Gauge().DataPoints().AppendEmpty()
-		dp.Attributes().InsertString("foo", "bar")
+		dp.Attributes().PutStr("foo", "bar")
 		dp.SetTimestamp(pcommon.Timestamp(1622848686000000000))
-		dp.SetDoubleVal(87.332)
+		dp.SetDoubleValue(87.332)
 	}
 	m := newMockOtelService(t)
 	t.Cleanup(m.Cleanup)
@@ -50,7 +49,7 @@ func TestOpenTelemetry(t *testing.T) {
 		Attributes:           map[string]string{"attr-key": "attr-val"},
 		metricsConverter:     metricsConverter,
 		grpcClientConn:       m.GrpcClient(),
-		metricsServiceClient: pmetricotlp.NewClient(m.GrpcClient()),
+		metricsServiceClient: pmetricotlp.NewGRPCClient(m.GrpcClient()),
 	}
 
 	input := testutil.MustMetric(
@@ -66,26 +65,21 @@ func TestOpenTelemetry(t *testing.T) {
 		time.Unix(0, 1622848686000000000))
 
 	err = plugin.Write([]telegraf.Metric{input})
-	if err != nil {
-		// TODO not sure why the service returns this error, but the data arrives as required by the test
-		// rpc error: code = Internal desc = grpc: error while marshaling: proto: Marshal called with nil
-		if !strings.Contains(err.Error(), "proto: Marshal called with nil") {
-			assert.NoError(t, err)
-		}
-	}
+	require.NoError(t, err)
 
 	got := m.GotMetrics()
 
-	expectJSON, err := pmetric.NewJSONMarshaler().MarshalMetrics(expect)
+	marshaller := pmetric.JSONMarshaler{}
+	expectJSON, err := marshaller.MarshalMetrics(expect)
 	require.NoError(t, err)
 
-	gotJSON, err := pmetric.NewJSONMarshaler().MarshalMetrics(got)
+	gotJSON, err := marshaller.MarshalMetrics(got)
 	require.NoError(t, err)
 
-	assert.JSONEq(t, string(expectJSON), string(gotJSON))
+	require.JSONEq(t, string(expectJSON), string(gotJSON))
 }
 
-var _ pmetricotlp.Server = (*mockOtelService)(nil)
+var _ pmetricotlp.GRPCServer = (*mockOtelService)(nil)
 
 type mockOtelService struct {
 	t          *testing.T
@@ -107,8 +101,8 @@ func newMockOtelService(t *testing.T) *mockOtelService {
 		grpcServer: grpcServer,
 	}
 
-	pmetricotlp.RegisterServer(grpcServer, mockOtelService)
-	go func() { assert.NoError(t, grpcServer.Serve(listener)) }()
+	pmetricotlp.RegisterGRPCServer(grpcServer, mockOtelService)
+	go func() { require.NoError(t, grpcServer.Serve(listener)) }()
 
 	grpcClient, err := grpc.Dial(listener.Addr().String(), grpc.WithTransportCredentials(insecure.NewCredentials()), grpc.WithBlock())
 	require.NoError(t, err)
@@ -118,7 +112,7 @@ func newMockOtelService(t *testing.T) *mockOtelService {
 }
 
 func (m *mockOtelService) Cleanup() {
-	assert.NoError(m.t, m.grpcClient.Close())
+	require.NoError(m.t, m.grpcClient.Close())
 	m.grpcServer.Stop()
 }
 
@@ -134,10 +128,11 @@ func (m *mockOtelService) Address() string {
 	return m.listener.Addr().String()
 }
 
-func (m *mockOtelService) Export(ctx context.Context, request pmetricotlp.Request) (pmetricotlp.Response, error) {
-	m.metrics = request.Metrics().Clone()
+func (m *mockOtelService) Export(ctx context.Context, request pmetricotlp.ExportRequest) (pmetricotlp.ExportResponse, error) {
+	m.metrics = pmetric.NewMetrics()
+	request.Metrics().CopyTo(m.metrics)
 	ctxMetadata, ok := metadata.FromIncomingContext(ctx)
-	assert.Equal(m.t, []string{"header1"}, ctxMetadata.Get("test"))
-	assert.True(m.t, ok)
-	return pmetricotlp.Response{}, nil
+	require.Equal(m.t, []string{"header1"}, ctxMetadata.Get("test"))
+	require.True(m.t, ok)
+	return pmetricotlp.NewExportResponse(), nil
 }
