@@ -75,10 +75,8 @@ const validJSONArrayTags = `
 `
 
 func TestParseValidJSON(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_test"}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
 	metrics, err := parser.Parse([]byte(validJSON))
@@ -125,10 +123,8 @@ func TestParseValidJSON(t *testing.T) {
 }
 
 func TestParseLineValidJSON(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_test"}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
 	metric, err := parser.ParseLine(validJSON)
@@ -162,12 +158,10 @@ func TestParseLineValidJSON(t *testing.T) {
 }
 
 func TestParseInvalidJSON(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_test"}
+	require.NoError(t, parser.Init())
 
-	_, err = parser.Parse([]byte(invalidJSON))
+	_, err := parser.Parse([]byte(invalidJSON))
 	require.Error(t, err)
 	_, err = parser.Parse([]byte(invalidJSON2))
 	require.Error(t, err)
@@ -176,47 +170,47 @@ func TestParseInvalidJSON(t *testing.T) {
 }
 
 func TestParseJSONImplicitStrictness(t *testing.T) {
-	parserImplicitNoStrict, err := New(&Config{
+	parserImplicitNoStrict := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "time",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parserImplicitNoStrict.Init())
 
-	_, err = parserImplicitNoStrict.Parse([]byte(mixedValidityJSON))
+	_, err := parserImplicitNoStrict.Parse([]byte(mixedValidityJSON))
 	require.NoError(t, err)
 }
 
 func TestParseJSONExplicitStrictnessFalse(t *testing.T) {
-	parserNoStrict, err := New(&Config{
+	parserNoStrict := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "time",
 		Strict:     false,
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parserNoStrict.Init())
 
-	_, err = parserNoStrict.Parse([]byte(mixedValidityJSON))
+	_, err := parserNoStrict.Parse([]byte(mixedValidityJSON))
 	require.NoError(t, err)
 }
 
 func TestParseJSONExplicitStrictnessTrue(t *testing.T) {
-	parserStrict, err := New(&Config{
+	parserStrict := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "time",
 		Strict:     true,
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parserStrict.Init())
 
-	_, err = parserStrict.Parse([]byte(mixedValidityJSON))
+	_, err := parserStrict.Parse([]byte(mixedValidityJSON))
 	require.Error(t, err)
 }
 
 func TestParseWithTagKeys(t *testing.T) {
 	// Test that strings not matching tag keys are ignored
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"wrongtagkey"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(validJSONTags))
 	require.NoError(t, err)
@@ -229,11 +223,11 @@ func TestParseWithTagKeys(t *testing.T) {
 	require.Equal(t, map[string]string{}, metrics[0].Tags())
 
 	// Test that single tag key is found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"mytag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err = parser.Parse([]byte(validJSONTags))
 	require.NoError(t, err)
@@ -248,11 +242,12 @@ func TestParseWithTagKeys(t *testing.T) {
 	}, metrics[0].Tags())
 
 	// Test that both tag keys are found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"mytag", "othertag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
+
 	metrics, err = parser.Parse([]byte(validJSONTags))
 	require.NoError(t, err)
 	require.Len(t, metrics, 1)
@@ -269,11 +264,12 @@ func TestParseWithTagKeys(t *testing.T) {
 
 func TestParseLineWithTagKeys(t *testing.T) {
 	// Test that strings not matching tag keys are ignored
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"wrongtagkey"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
+
 	metric, err := parser.ParseLine(validJSONTags)
 	require.NoError(t, err)
 	require.Equal(t, "json_test", metric.Name())
@@ -284,11 +280,11 @@ func TestParseLineWithTagKeys(t *testing.T) {
 	require.Equal(t, map[string]string{}, metric.Tags())
 
 	// Test that single tag key is found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"mytag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metric, err = parser.ParseLine(validJSONTags)
 	require.NoError(t, err)
@@ -302,11 +298,11 @@ func TestParseLineWithTagKeys(t *testing.T) {
 	}, metric.Tags())
 
 	// Test that both tag keys are found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"mytag", "othertag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metric, err = parser.ParseLine(validJSONTags)
 	require.NoError(t, err)
@@ -322,14 +318,12 @@ func TestParseLineWithTagKeys(t *testing.T) {
 }
 
 func TestParseValidJSONDefaultTags(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-		TagKeys:    []string{"mytag"},
-		DefaultTags: map[string]string{
-			"t4g": "default",
-		},
-	})
-	require.NoError(t, err)
+	parser := &Parser{
+		MetricName:  "json_test",
+		TagKeys:     []string{"mytag"},
+		DefaultTags: map[string]string{"t4g": "default"},
+	}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
 	metrics, err := parser.Parse([]byte(validJSON))
@@ -359,14 +353,12 @@ func TestParseValidJSONDefaultTags(t *testing.T) {
 
 // Test that default tags are overridden by tag keys
 func TestParseValidJSONDefaultTagsOverride(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-		TagKeys:    []string{"mytag"},
-		DefaultTags: map[string]string{
-			"mytag": "default",
-		},
-	})
-	require.NoError(t, err)
+	parser := &Parser{
+		MetricName:  "json_test",
+		TagKeys:     []string{"mytag"},
+		DefaultTags: map[string]string{"mytag": "default"},
+	}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
 	metrics, err := parser.Parse([]byte(validJSON))
@@ -395,10 +387,8 @@ func TestParseValidJSONDefaultTagsOverride(t *testing.T) {
 
 // Test that json arrays can be parsed
 func TestParseValidJSONArray(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_array_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_array_test"}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
 	metrics, err := parser.Parse([]byte(validJSONArray))
@@ -431,11 +421,11 @@ func TestParseValidJSONArray(t *testing.T) {
 
 func TestParseArrayWithTagKeys(t *testing.T) {
 	// Test that strings not matching tag keys are ignored
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_array_test",
 		TagKeys:    []string{"wrongtagkey"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(validJSONArrayTags))
 	require.NoError(t, err)
@@ -455,11 +445,11 @@ func TestParseArrayWithTagKeys(t *testing.T) {
 	require.Equal(t, map[string]string{}, metrics[1].Tags())
 
 	// Test that single tag key is found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_array_test",
 		TagKeys:    []string{"mytag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err = parser.Parse([]byte(validJSONArrayTags))
 	require.NoError(t, err)
@@ -483,11 +473,11 @@ func TestParseArrayWithTagKeys(t *testing.T) {
 	}, metrics[1].Tags())
 
 	// Test that both tag keys are found and applied
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_array_test",
 		TagKeys:    []string{"mytag", "othertag"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err = parser.Parse([]byte(validJSONArrayTags))
 	require.NoError(t, err)
@@ -516,17 +506,15 @@ func TestParseArrayWithTagKeys(t *testing.T) {
 var jsonBOM = []byte("\xef\xbb\xbf[{\"value\":17}]")
 
 func TestHttpJsonBOM(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_test"}
+	require.NoError(t, parser.Init())
 
 	// Most basic vanilla test
-	_, err = parser.Parse(jsonBOM)
+	_, err := parser.Parse(jsonBOM)
 	require.NoError(t, err)
 }
 
-//for testing issue #4260
+// for testing issue #4260
 func TestJSONParseNestedArray(t *testing.T) {
 	testString := `{
 	"total_devices": 5,
@@ -546,11 +534,11 @@ func TestJSONParseNestedArray(t *testing.T) {
 	}
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"total_devices", "total_threads", "shares_tester3_fun"},
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.Len(t, metrics, 1)
@@ -575,14 +563,14 @@ func TestJSONQueryErrorOnArray(t *testing.T) {
 		}
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{},
 		Query:      "shares.myArr",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
-	_, err = parser.Parse([]byte(testString))
+	_, err := parser.Parse([]byte(testString))
 	require.Error(t, err)
 }
 
@@ -609,12 +597,12 @@ func TestArrayOfObjects(t *testing.T) {
 		"more_stuff":"junk"
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TagKeys:    []string{"ice"},
 		Query:      "meta.shares",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
@@ -636,13 +624,13 @@ func TestUseCaseJSONQuery(t *testing.T) {
 		}
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName:   "json_test",
 		StringFields: []string{"last"},
 		TagKeys:      []string{"first"},
 		Query:        "obj.friends",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
@@ -672,12 +660,13 @@ func TestTimeParser(t *testing.T) {
 		}
 	]`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "b_time",
 		TimeFormat: "02 Jan 06 15:04 MST",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
+
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
 	require.Equal(t, 2, len(metrics))
@@ -689,13 +678,14 @@ func TestTimeParserWithTimezone(t *testing.T) {
 		"time": "04 Jan 06 15:04"
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "time",
 		TimeFormat: "02 Jan 06 15:04",
 		Timezone:   "America/New_York",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
+
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
 	require.Equal(t, 1, len(metrics))
@@ -724,12 +714,12 @@ func TestUnixTimeParser(t *testing.T) {
 		}
 	]`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "b_time",
 		TimeFormat: "unix",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
@@ -759,12 +749,12 @@ func TestUnixMsTimeParser(t *testing.T) {
 		}
 	]`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "b_time",
 		TimeFormat: "unix_ms",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
@@ -783,12 +773,12 @@ func TestTimeErrors(t *testing.T) {
 		"my_tag_2": "baz"
 	}`
 
-	parser, err := New(&Config{
+	parser := &Parser{
 		MetricName: "json_test",
 		TimeKey:    "b_time",
 		TimeFormat: "02 January 06 15:04 MST",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.Error(t, err)
@@ -803,12 +793,12 @@ func TestTimeErrors(t *testing.T) {
 		"my_tag_2": "baz"
 	}`
 
-	parser, err = New(&Config{
+	parser = &Parser{
 		MetricName: "json_test",
 		TimeKey:    "b_time",
 		TimeFormat: "02 January 06 15:04 MST",
-	})
-	require.NoError(t, err)
+	}
+	require.NoError(t, parser.Init())
 
 	metrics, err = parser.Parse([]byte(testString2))
 	require.Error(t, err)
@@ -817,10 +807,8 @@ func TestTimeErrors(t *testing.T) {
 }
 
 func TestShareTimestamp(t *testing.T) {
-	parser, err := New(&Config{
-		MetricName: "json_test",
-	})
-	require.NoError(t, err)
+	parser := &Parser{MetricName: "json_test"}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(validJSONArrayMultiple))
 	require.NoError(t, err)
@@ -839,10 +827,8 @@ func TestNameKey(t *testing.T) {
 		"my_tag_2": "baz"
 	}`
 
-	parser, err := New(&Config{
-		NameKey: "b_c",
-	})
-	require.NoError(t, err)
+	parser := &Parser{NameKey: "b_c"}
+	require.NoError(t, parser.Init())
 
 	metrics, err := parser.Parse([]byte(testString))
 	require.NoError(t, err)
@@ -852,23 +838,23 @@ func TestNameKey(t *testing.T) {
 func TestParseArrayWithWrongType(t *testing.T) {
 	data := `[{"answer": 42}, 123]`
 
-	parser, err := New(&Config{})
-	require.NoError(t, err)
+	parser := &Parser{}
+	require.NoError(t, parser.Init())
 
-	_, err = parser.Parse([]byte(data))
+	_, err := parser.Parse([]byte(data))
 	require.Error(t, err)
 }
 
 func TestParse(t *testing.T) {
 	tests := []struct {
 		name     string
-		config   *Config
+		parser   *Parser
 		input    []byte
 		expected []telegraf.Metric
 	}{
 		{
 			name: "tag keys with underscore issue 6705",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json",
 				TagKeys:    []string{"metric___name__"},
 			},
@@ -888,25 +874,25 @@ func TestParse(t *testing.T) {
 		},
 		{
 			name:     "parse empty array",
-			config:   &Config{},
+			parser:   &Parser{},
 			input:    []byte(`[]`),
 			expected: []telegraf.Metric{},
 		},
 		{
 			name:     "parse null",
-			config:   &Config{},
+			parser:   &Parser{},
 			input:    []byte(`null`),
 			expected: []telegraf.Metric{},
 		},
 		{
 			name:     "parse null with query",
-			config:   &Config{Query: "result.data"},
+			parser:   &Parser{Query: "result.data"},
 			input:    []byte(`{"error":null,"result":{"data":null,"items_per_page":10,"total_items":0,"total_pages":0}}`),
 			expected: []telegraf.Metric{},
 		},
 		{
 			name: "parse simple array",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json",
 			},
 			input: []byte(`[{"answer": 42}]`),
@@ -923,7 +909,7 @@ func TestParse(t *testing.T) {
 		},
 		{
 			name: "string field glob",
-			config: &Config{
+			parser: &Parser{
 				MetricName:   "json",
 				StringFields: []string{"*"},
 			},
@@ -947,7 +933,7 @@ func TestParse(t *testing.T) {
 		},
 		{
 			name: "time key is deleted from fields",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json",
 				TimeKey:    "timestamp",
 				TimeFormat: "unix",
@@ -972,8 +958,8 @@ func TestParse(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			parser, err := New(tt.config)
-			require.NoError(t, err)
+			parser := tt.parser
+			require.NoError(t, parser.Init())
 
 			actual, err := parser.Parse(tt.input)
 			require.NoError(t, err)
@@ -986,13 +972,13 @@ func TestParse(t *testing.T) {
 func TestParseWithWildcardTagKeys(t *testing.T) {
 	var tests = []struct {
 		name     string
-		config   *Config
+		parser   *Parser
 		input    []byte
 		expected []telegraf.Metric
 	}{
 		{
 			name: "wildcard matching with tags nested within object",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"tags_object_*"},
 			},
@@ -1014,7 +1000,7 @@ func TestParseWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "wildcard matching with keys containing tag",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"*tag"},
 			},
@@ -1038,7 +1024,7 @@ func TestParseWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "strings not matching tag keys are still also ignored",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"wrongtagkey", "tags_object_*"},
 			},
@@ -1060,7 +1046,7 @@ func TestParseWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "single tag key is also found and applied",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"mytag", "tags_object_*"},
 			},
@@ -1084,8 +1070,8 @@ func TestParseWithWildcardTagKeys(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			parser, err := New(tt.config)
-			require.NoError(t, err)
+			parser := tt.parser
+			require.NoError(t, parser.Init())
 
 			actual, err := parser.Parse(tt.input)
 			require.NoError(t, err)
@@ -1097,13 +1083,13 @@ func TestParseWithWildcardTagKeys(t *testing.T) {
 func TestParseLineWithWildcardTagKeys(t *testing.T) {
 	var tests = []struct {
 		name     string
-		config   *Config
+		parser   *Parser
 		input    string
 		expected telegraf.Metric
 	}{
 		{
 			name: "wildcard matching with tags nested within object",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"tags_object_*"},
 			},
@@ -1123,7 +1109,7 @@ func TestParseLineWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "wildcard matching with keys containing tag",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"*tag"},
 			},
@@ -1145,7 +1131,7 @@ func TestParseLineWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "strings not matching tag keys are ignored",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"wrongtagkey", "tags_object_*"},
 			},
@@ -1165,7 +1151,7 @@ func TestParseLineWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "single tag key is also found and applied",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_test",
 				TagKeys:    []string{"mytag", "tags_object_*"},
 			},
@@ -1188,8 +1174,8 @@ func TestParseLineWithWildcardTagKeys(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			parser, err := New(tt.config)
-			require.NoError(t, err)
+			parser := tt.parser
+			require.NoError(t, parser.Init())
 
 			actual, err := parser.ParseLine(tt.input)
 			require.NoError(t, err)
@@ -1202,13 +1188,13 @@ func TestParseLineWithWildcardTagKeys(t *testing.T) {
 func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 	var tests = []struct {
 		name     string
-		config   *Config
+		parser   *Parser
 		input    []byte
 		expected []telegraf.Metric
 	}{
 		{
 			name: "wildcard matching with keys containing tag within array works",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_array_test",
 				TagKeys:    []string{"*tag"},
 			},
@@ -1246,7 +1232,7 @@ func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: " wildcard matching with tags nested array within object works",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_array_test",
 				TagKeys:    []string{"tags_array_*"},
 			},
@@ -1280,7 +1266,7 @@ func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "strings not matching tag keys are still also ignored",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_array_test",
 				TagKeys:    []string{"mytag", "*tag"},
 			},
@@ -1318,7 +1304,7 @@ func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 		},
 		{
 			name: "single tag key is also found and applied",
-			config: &Config{
+			parser: &Parser{
 				MetricName: "json_array_test",
 				TagKeys:    []string{"anothert", "*tag"},
 			},
@@ -1360,8 +1346,8 @@ func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			parser, err := New(tt.config)
-			require.NoError(t, err)
+			parser := tt.parser
+			require.NoError(t, parser.Init())
 
 			actual, err := parser.Parse(tt.input)
 			require.NoError(t, err)
@@ -1369,5 +1355,4 @@ func TestParseArrayWithWildcardTagKeys(t *testing.T) {
 			testutil.RequireMetricsEqual(t, tt.expected, actual, testutil.IgnoreTime())
 		})
 	}
-
 }
