@@ -43,9 +43,8 @@ type Serializer struct {
 	config FormatConfig
 }
 
-func NewSerializer(config FormatConfig) (*Serializer, error) {
-	s := &Serializer{config: config}
-	return s, nil
+func NewSerializer(config FormatConfig) *Serializer {
+	return &Serializer{config: config}
 }
 
 func (s *Serializer) Serialize(metric telegraf.Metric) ([]byte, error) {
@@ -195,7 +194,7 @@ func (s *Serializer) SerializeBatch(metrics []telegraf.Metric) ([]byte, error) {
 			// sample then we can skip over it.
 			m, ok := entries[metrickey]
 			if ok {
-				if metric.Time().Before(time.Unix(m.Samples[0].Timestamp, 0)) {
+				if metric.Time().Before(time.Unix(0, m.Samples[0].Timestamp*1_000_000)) {
 					continue
 				}
 			}
@@ -339,5 +338,11 @@ func getPromTS(name string, labels []prompb.Label, value float64, ts time.Time)
 		Name:  "__name__",
 		Value: name,
 	})
+
+	// we sort the labels since Prometheus TSDB does not like out of order labels
+	sort.Slice(labels, func(i, j int) bool {
+		return labels[i].Name < labels[j].Name
+	})
+
 	return MakeMetricKey(labels), prompb.TimeSeries{Labels: labels, Samples: sample}
 }
